@@ -1,9 +1,12 @@
 package CloudFlare::Client;
 # ABSTRACT: Object Orientated Interface to CloudFlare client API
 
-use Modern::Perl '2013';
-use autodie      ':all';
-no  indirect     'fatal';
+# Or Kavorka will explode
+use 5.014;
+use strict; use warnings;
+use mro 'c3';
+use IO qw(Handle File Dir);
+use autodie ':all'; no indirect 'fatal';
 use namespace::autoclean;
 
 use Readonly;
@@ -19,7 +22,7 @@ use LWP::UserAgent       6.02;
 use LWP::Protocol::https 6.02;
 use JSON::Any;
 
-our $VERSION = '0.05_1'; # TRIAL VERSION
+our $VERSION = '0.05_2'; # TRIAL VERSION
 
 # CF credentials
 has '_user' => (
@@ -173,12 +176,10 @@ CloudFlare::Client - Object Orientated Interface to CloudFlare client API
 
 =head1 VERSION
 
-version 0.05_1
+version 0.05_2
 
 =head1 SYNOPSIS
 
-Provides an object orientated interface to the CloudFlare client API
-
     use CloudFlare::Client;
 
     my $api = CloudFlare::Client::->new(
@@ -187,12 +188,16 @@ Provides an object orientated interface to the CloudFlare client API
     $api->stats;
     ...
 
-Please see the documentation at
-L<https://www.cloudflare.com/docs/client-api.html> for information the
-CloudFlare client API and its arguments. Optional arguments are passed
-in as a hash with keys as given in the docs
+=head1 OVERVIEW
 
-Successful API calls return the response section from the upstream JSON API. Failures for whatever reason throw exceptions under the CloudFlare::Client::Exception:: namespace
+Please see the documentation at
+L<https://www.cloudflare.com/docs/client-api.html> for information on the
+CloudFlare client API and its arguments. Optional arguments are passed in as a
+hash with keys as given in the docs
+
+Successful API calls return the response section from the upstream JSON
+API. Failures for whatever reason throw exceptions under the
+CloudFlare::Client::Exception:: namespace
 
 =head1 METHODS
 
@@ -300,11 +305,71 @@ Construct a new API object
 
 =for test_synopsis my ($CF_USER, $CF_KEY);
 
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Mojo::Cloudflare|Mojo::Cloudflare>
+
+=item *
+
+L<WebService::CloudFlare::Host|WebService::CloudFlare::Host>
+
+=back
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc CloudFlare::Client
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/CloudFlare-Client>
+
+=back
+
+=head2 Email
+
+You can email the author of this module at C<me+dev@peter-r.co.uk> asking for help with any problems you have.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/pwr22/cloudflare-client>
+
+  git clone git://github.com/pwr22/cloudflare-client.git
+
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-cloudflare-client
-at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CloudFlare-Client>
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/pwr22/cloudflare-client/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 ACKNOWLEDGEMENTS
 
