@@ -1,16 +1,17 @@
 package CloudFlare::Client::Exception::Upstream;
 # ABSTRACT: Upstream CloudFlare API Exception
 
-use Modern::Perl '2013';
-use autodie      ':all';
-no  indirect     'fatal';
+use strict; use warnings;
+use mro 'c3';
+use IO qw(Handle File Dir);
+use autodie ':all'; no indirect 'fatal';
 use namespace::autoclean;
 
 use Readonly;
-use Moo; use MooX::StrictConstructor;
+use Moose; use MooseX::StrictConstructor;
 use CloudFlare::Client::Types 'ErrorCode';
 
-our $VERSION = '0.05_1'; # TRIAL VERSION
+our $VERSION = '0.05_2'; # TRIAL VERSION
 
 extends 'Throwable::Error';
 
@@ -33,12 +34,10 @@ CloudFlare::Client::Exception::Upstream - Upstream CloudFlare API Exception
 
 =head1 VERSION
 
-version 0.05_1
+version 0.05_2
 
 =head1 SYNOPSIS
 
-Exception class that propagates errors from the CloudFlare API
-
     use CloudFlare::Client::Exception::Upstream;
 
     CloudFlare::Client::Exception::Upstream::->throw(
@@ -61,7 +60,7 @@ The error message thrown upstream, readonly.
 =head2 errorCode
 
 The error code thrown upstream, readonly. Valid values are undef,
-E_UNAUTH, E_INVLDINPUT or E_MAXAPI.
+E_UNAUTH, E_INVLDINPUT or E_MAXAPI. Readonly.
 
 =head1 METHODS
 
@@ -88,60 +87,68 @@ Construct a new exception
         errorcode => 'E_MAXAPI'
     );
 
-=head1 INHERITANCE
+=head1 SEE ALSO
 
-See L<Throwable::Error>
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-cloudflare-client
-at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CloudFlare-Client>.
-I will be notified, and then you'll automatically be notified of
-progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc CloudFlare::Client::Exception::Upstream
-
-You can also look for information at:
+Please see those modules/websites for more information related to this module.
 
 =over 4
 
 =item *
 
-DDFlare
-
-L<https://bitbucket.org/pwr22/ddflare>
-
-=item *
-
-RT: CPAN's request tracker (report bugs here)
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=CloudFlare-Client>
-
-=item *
-
-AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/CloudFlare-Client>
-
-=item *
-
-CPAN Ratings
-
-L<http://cpanratings.perl.org/d/CloudFlare-Client>
-
-=item *
-
-Search CPAN
-
-L<http://search.cpan.org/dist/CloudFlare-Client/>
+L<CloudFlare::Client|CloudFlare::Client>
 
 =back
 
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc CloudFlare::Client::Exception::Upstream
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/CloudFlare-Client>
+
+=back
+
+=head2 Email
+
+You can email the author of this module at C<me+dev@peter-r.co.uk> asking for help with any problems you have.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/pwr22/cloudflare-client>
+
+  git clone git://github.com/pwr22/cloudflare-client.git
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/pwr22/cloudflare-client/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Peter Roberts <me+dev@peter-r.co.uk>
